@@ -1,18 +1,23 @@
 """Set User-Agent header per spider or use a default value from settings"""
 
-from scrapy.conf import settings
 from scrapy.utils.python import WeakKeyCache
 
 
 class UserAgentMiddleware(object):
     """This middleware allows spiders to override the user_agent"""
 
-    def __init__(self, settings=settings):
+    def __init__(self, user_agent='Scrapy'):
         self.cache = WeakKeyCache(self._user_agent)
-        self.default_useragent = settings.get('USER_AGENT')
+        self.user_agent = user_agent
+
+    @classmethod
+    def from_crawler(cls, crawler):
+        return cls(crawler.settings['USER_AGENT'])
 
     def _user_agent(self, spider):
-        return getattr(spider, 'user_agent', None) or self.default_useragent
+        if hasattr(spider, 'user_agent'):
+            return spider.user_agent
+        return self.user_agent
 
     def process_request(self, request, spider):
         ua = self.cache[spider]
