@@ -3,8 +3,9 @@ import unittest, tempfile, shutil, time
 from scrapy.http import Response, HtmlResponse, Request
 from scrapy.spider import BaseSpider
 from scrapy.contrib.downloadermiddleware.httpcache import FilesystemCacheStorage, HttpCacheMiddleware
-from scrapy.conf import Settings
+from scrapy.settings import Settings
 from scrapy.exceptions import IgnoreRequest
+from scrapy.utils.test import get_crawler
 
 
 class HttpCacheMiddlewareTest(unittest.TestCase):
@@ -12,16 +13,20 @@ class HttpCacheMiddlewareTest(unittest.TestCase):
     storage_class = FilesystemCacheStorage
 
     def setUp(self):
+        self.crawler = get_crawler()
         self.spider = BaseSpider('example.com')
         self.tmpdir = tempfile.mkdtemp()
         self.request = Request('http://www.example.com', headers={'User-Agent': 'test'})
         self.response = Response('http://www.example.com', headers={'Content-Type': 'text/html'}, body='test body', status=202)
+        self.crawler.stats.open_spider(self.spider)
 
     def tearDown(self):
+        self.crawler.stats.close_spider(self.spider, '')
         shutil.rmtree(self.tmpdir)
 
     def _get_settings(self, **new_settings):
         settings = {
+            'HTTPCACHE_ENABLED': True,
             'HTTPCACHE_DIR': self.tmpdir,
             'HTTPCACHE_EXPIRATION_SECS': 1,
             'HTTPCACHE_IGNORE_HTTP_CODES': [],
@@ -33,7 +38,9 @@ class HttpCacheMiddlewareTest(unittest.TestCase):
         return self.storage_class(self._get_settings(**new_settings))
 
     def _get_middleware(self, **new_settings):
-        return HttpCacheMiddleware(self._get_settings(**new_settings))
+        mw = HttpCacheMiddleware(self._get_settings(**new_settings), self.crawler.stats)
+        mw.spider_opened(self.spider)
+        return mw
 
     def test_storage(self):
         storage = self._get_storage()
@@ -46,21 +53,15 @@ class HttpCacheMiddlewareTest(unittest.TestCase):
         time.sleep(2) # wait for cache to expire
         assert storage.retrieve_response(self.spider, request2) is None
 
-    def test_storage_expire_immediately(self):
+    def test_storage_never_expire(self):
         storage = self._get_storage(HTTPCACHE_EXPIRATION_SECS=0)
         assert storage.retrieve_response(self.spider, self.request) is None
         storage.store_response(self.spider, self.request, self.response)
-        time.sleep(0.1) # required for win32
-        assert storage.retrieve_response(self.spider, self.request) is None
-
-    def test_storage_never_expire(self):
-        storage = self._get_storage(HTTPCACHE_EXPIRATION_SECS=-1)
-        assert storage.retrieve_response(self.spider, self.request) is None
-        storage.store_response(self.spider, self.request, self.response)
+        time.sleep(0.5) # give the chance to expire
         assert storage.retrieve_response(self.spider, self.request)
 
     def test_middleware(self):
-        mw = HttpCacheMiddleware(self._get_settings())
+        mw = self._get_middleware()
         assert mw.process_request(self.request, self.spider) is None
         mw.process_response(self.request, self.response, self.spider)
         response = mw.process_request(self.request, self.spider)
@@ -69,7 +70,7 @@ class HttpCacheMiddlewareTest(unittest.TestCase):
         assert 'cached' in response.flags
 
     def test_different_request_response_urls(self):
-        mw = HttpCacheMiddleware(self._get_settings())
+        mw = self._get_middleware()
         req = Request('http://host.com/path')
         res = Response('http://host2.net/test.html')
         assert mw.process_request(req, self.spider) is None
